@@ -251,6 +251,20 @@ t_fcgi_server *fcgi_server_match(t_fcgi_server *fcgi_server, t_charlist *fastcgi
 	return NULL;
 }
 
+t_fcgi_server *find_fcgi_server(t_fcgi_server *fcgi_server, char *id) {
+	if (id == NULL) {
+		return NULL;
+	}
+
+	while (fcgi_server != NULL) {
+		if (strcasecmp(fcgi_server->fcgi_id, id) == 0) {
+			return fcgi_server;
+		}
+		fcgi_server = fcgi_server->next;
+	}
+
+	return NULL;
+}
 
 /*
  * Normal CGI processes
