@@ -29,6 +29,9 @@ int  reban_ip(t_ip_addr *ip);
 void check_ban_list(t_config *config);
 int  unban_ip(t_ip_addr *ip);
 
+int  register_wrong_password(t_session *session);
+void remove_wrong_password_list(t_config *config);
+
 #ifdef HAVE_COMMAND
 void print_client_list(FILE *fp);
 int number_of_clients(void);
