@@ -47,8 +47,8 @@
 #ifdef HAVE_CACHE
 #include "cache.h"
 #endif
-#ifdef HAVE_REWRITE
-#include "rewrite.h"
+#ifdef HAVE_TOOLKIT
+#include "toolkit.h"
 #endif
 #ifdef HAVE_XSLT
 #include "xslt.h"
@@ -101,8 +101,11 @@ char *version_string = "Hiawatha v"VERSION
 #ifdef HAVE_SSL
 			", SSL"
 #endif
-#ifdef HAVE_REWRITE
-			", URL rewrite"
+#ifdef HAVE_TOOLKIT
+			", URL toolkit"
+#endif
+#ifdef HAVE_XSLT
+			", XSLT"
 #endif
 ;
 
@@ -151,6 +154,11 @@ void touch_logfiles(t_config *config, char *dir) {
 t_cgi_type check_target_is_cgi(t_session *session) {
 	t_cgi_handler *cgi;
 
+#ifdef HAVE_TOOLKIT
+	if ((session->fcgi_server = find_fcgi_server(session->config->fcgi_server, session->toolkit_fastcgi)) != NULL) {
+		session->cgi_type = fastcgi;
+	} else 
+#endif
 	if ((session->fcgi_server = fcgi_server_match(session->config->fcgi_server, &(session->host->fast_cgi), session->file_on_disk)) != NULL) {
 		session->cgi_type = fastcgi;
 	} else if (in_charlist(file_extension(session->file_on_disk), &(session->config->cgi_extension))) {
@@ -288,17 +296,8 @@ int run_alter_program(t_session *session) {
 	} else if (pid == -1) {
 		log_file_error(session, session->host->run_on_alter, "RunOnAlter fork() error");
 		return -1;
-#ifdef OPENBSD
-	} else {
-		int loop = session->host->time_for_cgi * 4;
-
-		while (loop > 0) {
-			usleep(250000);
-			if (waitpid(pid, NULL, WNOHANG) > 0) {
-				break;
-			}
-		}
-#endif
+	} else if (session->config->wait_for_cgi) {
+		waitpid(pid, NULL, 0);
 	}
 
 	return 0;
@@ -807,7 +806,7 @@ int serve_client(t_session *session) {
 	bool file_not_found = false;
 	t_access access;
 	t_fsbool is_dir;
-#ifdef HAVE_REWRITE
+#ifdef HAVE_TOOLKIT
 	int i;
 	char *new_uri;
 #endif
@@ -846,12 +845,12 @@ int serve_client(t_session *session) {
 	}
 	session->host->access_time = time(NULL);
 
-#ifdef HAVE_REWRITE
-	/* URL rewrite
+#ifdef HAVE_TOOLKIT
+	/* URL toolkit
 	 */
 	if ((session->request_method != PUT) && (session->request_method != DELETE)) {
-		for (i = 0; i < session->host->rewrite_rules.size; i++) {
-			if ((result = rewrite_url(session->uri, session->host->rewrite_rules.item[i], session->config->url_rewrite, &new_uri, session->host->website_root)) == RW_ERROR) {
+		for (i = 0; i < session->host->toolkit_rules.size; i++) {
+			if ((result = use_toolkit(session->uri, session->host->toolkit_rules.item[i], session->config->url_toolkit, &new_uri, session->host->website_root, &(session->toolkit_fastcgi))) == UT_ERROR) {
 				return 500;
 			}
 			if (new_uri != NULL) {
@@ -865,13 +864,13 @@ int serve_client(t_session *session) {
 				session->uri = new_uri;
 			}
 
-			if (result == RW_REDIRECT) {
+			if (result == UT_REDIRECT) {
 				session->location = strdup(new_uri);
 				session->cause_of_301 = location;
 				return 301;
 			}
-			if (result == RW_DENY_ACCESS) {
-				log_error(session, "access denied via URL rewrite rule");
+			if (result == UT_DENY_ACCESS) {
+				log_error(session, "access denied via URL toolkit rule");
 				return 403;
 			}
 		}
@@ -880,14 +879,9 @@ int serve_client(t_session *session) {
 
 	/* Find GET data
 	 */
-	qmark = session->uri;
-	while (*qmark != '\0') {
-		if (*qmark == '?') {
-			*qmark = '\0';
-			session->vars = qmark + 1;
-			break;
-		}
-		qmark++;
+	if ((qmark = strchr(session->uri, '?')) != NULL) {
+		*qmark = '\0';
+		session->vars = qmark + 1;
 	}
 
 	url_decode(session->uri);
@@ -1051,6 +1045,10 @@ int serve_client(t_session *session) {
 		case POST:
 			if (session->cgi_type != no_cgi) {
 				result = execute_cgi(session);
+#ifdef HAVE_XSLT
+			} else if (can_transform_with_xslt(session)) {
+				result = handle_xml_file(session);
+#endif
 			} else {
 				result = 405;
 			}
@@ -1524,15 +1522,6 @@ int run_server(t_settings *settings) {
 	struct stat        status;
 	mode_t             access_rights;
 
-	signal(SIGPIPE, SIG_IGN);
-#ifndef OPENBSD
-	signal(SIGCHLD, SIG_IGN);
-#endif
-	signal(SIGTSTP, SIG_IGN);
-	signal(SIGABRT, SIG_IGN);
-	signal(SIGQUIT, SIG_IGN);
-	signal(SIGSEGV, SEGV_handler);
-
 	config = default_config();
 	if (chdir(settings->config_dir) == -1) {
 		perror(settings->config_dir);
@@ -1556,6 +1545,15 @@ int run_server(t_settings *settings) {
 		return EXIT_SUCCESS;
 	}
 	
+	if (config->wait_for_cgi == false) {
+		signal(SIGCHLD, SIG_IGN);
+	}
+	signal(SIGPIPE, SIG_IGN);
+	signal(SIGTSTP, SIG_IGN);
+	signal(SIGABRT, SIG_IGN);
+	signal(SIGQUIT, SIG_IGN);
+	signal(SIGSEGV, SEGV_handler);
+
 	/* Bind Serverports
 	 */
 	if (bind_sockets(config->binding) == -1) {
