@@ -13,6 +13,7 @@
 #include "libstr.h"
 #include "liblist.h"
 #include "libmd5.h"
+#include "client.h"
 #include "httpauth.h"
 #include "log.h"
 
@@ -134,9 +135,13 @@ static bool basic_http_authentication(t_session *session, char *auth_str) {
 					 */
 					if (strcmp(encrypted, passwd) == 0) {
 						retval = ((session->remote_user = strdup(auth_user)) != NULL);
+					} else {
+						register_wrong_password(session);
 					}
 				}
 				free(passwd);
+			} else {
+				register_wrong_password(session);
 			}
 		}
 	}
@@ -260,9 +265,13 @@ static bool digest_http_authentication(t_session *session, char *auth_str) {
 			 */
 			if (strcmp(result, response) == 0) {
 				retval = ((session->remote_user = strdup(username)) != NULL);
+			} else {
+				register_wrong_password(session);
 			}
 		} while (false);
 		free(passwd);
+	} else {
+		register_wrong_password(session);
 	}
 
 	return retval;
