@@ -222,6 +222,11 @@ void md5_hash(char *string, int length, char hash[33]) {
 	unsigned char digest[16];
 	int i;
 
+	if (string == NULL) {	
+		hash[0] = '\0';
+		return;
+	}
+
 	MD5Init(&ctx);
 	MD5Update(&ctx, (unsigned char*)string, length);
 	MD5Final(digest, &ctx);
