@@ -7,7 +7,7 @@
 
 void ssl_init(char *buffer, int size);
 SSL_CTX *ssl_binding(char *keyfile, char *CA_cert, int verify_depth, char *dh_file, char *ciphers);
-bool ssl_accept(int sock, SSL **ssl, SSL_CTX *context);
+int  ssl_accept(int sock, SSL **ssl, SSL_CTX *context);
 int  ssl_receive(SSL *ssl, char *buffer, unsigned int maxlength);
 int  ssl_send(SSL *ssl, char *buffer, unsigned int length);
 int  ssl_close(SSL **ssl);
