@@ -241,7 +241,7 @@ t_config *read_config(char *config_file) {
 	line[MAX_CONFIG_LINE] = '\0';
 	while (fgets(line, MAX_CONFIG_LINE, fp) != NULL) {
 		linenr++;
-		data = strip_line(line);
+		data = uncomment(line);
 		if (*data != '\0') {
 			if (parse_line(config, data) == -1) {
 				fprintf(stderr, "Syntax error in %s on line %d\n", config_file, linenr);
