@@ -22,8 +22,8 @@
 #define MAX_UPLOAD_SIZE         100
 
 enum t_section { syntax_error = -1, none, binding, virtual_host, directory, fcgi_server
-#ifdef HAVE_REWRITE
-	, url_rewrite
+#ifdef HAVE_TOOLKIT
+	, url_toolkit
 #endif
 	};
 
@@ -71,8 +71,8 @@ static t_host *new_host(void) {
 		init_charlist(&(host->required_binding));
 		init_charlist(&(host->required_group));
 		init_charlist(&(host->alter_group));
-#ifdef HAVE_REWRITE
-		init_charlist(&(host->rewrite_rules));
+#ifdef HAVE_TOOLKIT
+		init_charlist(&(host->toolkit_rules));
 #endif
 		host->wrap_cgi           = NULL;
 		init_groups(&(host->groups));
@@ -192,21 +192,21 @@ static t_binding *new_binding(void) {
 	return binding;
 }
 
-#ifdef HAVE_REWRITE
-t_url_rewrite *new_url_rewrite(void) {
-	t_url_rewrite *url_rewrite;
+#ifdef HAVE_TOOLKIT
+t_url_toolkit *new_url_toolkit(void) {
+	t_url_toolkit *url_toolkit;
 
-	if ((url_rewrite = (t_url_rewrite*)malloc(sizeof(t_url_rewrite))) != NULL) {
-		url_rewrite->rewrite_id = NULL;
-		url_rewrite->rewrite_rule = NULL;
+	if ((url_toolkit = (t_url_toolkit*)malloc(sizeof(t_url_toolkit))) != NULL) {
+		url_toolkit->toolkit_id = NULL;
+		url_toolkit->toolkit_rule = NULL;
 
-		url_rewrite->next = NULL;
+		url_toolkit->next = NULL;
 	} else {
-		perror("new_url_rewrite()");
+		perror("new_url_toolkit()");
 		exit(EXIT_FAILURE);
 	}
 
-	return url_rewrite;
+	return url_toolkit;
 }
 #endif
 
@@ -237,6 +237,7 @@ t_config *default_config(void) {
 		config->total_connections  = 100;
 		config->connections_per_ip = 10;
 		config->kill_timedout_cgi  = true;
+		config->wait_for_cgi       = true;
 		config->first_host         = new_host();
 		config->mimetype           = NULL;
 		config->directory          = NULL;
@@ -271,8 +272,8 @@ t_config *default_config(void) {
 		config->fcgi_server        = NULL;
 		config->upload_directory   = UPLOAD_DIR;
 		config->create_upload_dir  = false;
-#ifdef HAVE_REWRITE
-		config->url_rewrite        = NULL;
+#ifdef HAVE_TOOLKIT
+		config->url_toolkit        = NULL;
 #endif
 #ifdef CYGWIN
 		config->platform           = windows;
@@ -597,8 +598,8 @@ int check_configuration(t_config *config) {
 		fcgi_server = fcgi_server->next;
 	}
 
-#ifdef HAVE_REWRITE
-	if (rewrite_rules_oke(config->url_rewrite) == false) {
+#ifdef HAVE_TOOLKIT
+	if (toolkit_rules_oke(config->url_toolkit) == false) {
 		return -1;
 	}
 #endif
@@ -868,7 +869,10 @@ static bool system_setting(char *key, char *value, t_config *config) {
 			}
 		}
 	} else if (strcmp(key, "serverstring") == 0) {
-		if (strlen(value) < 128) {
+		if ((strcmp(value, "none") == 0) || (strcmp(value, "-") == 0)) {
+			config->server_string = NULL;
+			return true;
+		} else if (strlen(value) < 128) {
 			if ((config->server_string = strdup(remove_spaces(value))) != NULL) {
 				return true;
 			}
@@ -918,6 +922,10 @@ static bool system_setting(char *key, char *value, t_config *config) {
 				return true;
 			}
 		}
+	} else if (strcmp(key, "waitforcgi") == 0) {
+		if (parse_yesno(value, &(config->wait_for_cgi)) == 0) {
+			return true;
+		}
 	} else if (strcmp(key, "wrapusercgi") == 0) {
 		if (parse_yesno(value, &(config->wrap_user_cgi)) == 0) {
 			return true;
@@ -1153,9 +1161,9 @@ static bool host_setting(char *key, char *value, t_host *host) {
 		if (parse_charlist(value, &(host->required_binding)) == 0) {
 			return true;
 		}
-#ifdef HAVE_REWRITE
-	} else if (strcmp(key, "rewriteurl") == 0) {
-		if (parse_charlist(value, &(host->rewrite_rules)) == 0) {
+#ifdef HAVE_TOOLKIT
+	} else if (strcmp(key, "usetoolkit") == 0) {
+		if (parse_charlist(value, &(host->toolkit_rules)) == 0) {
 			return true;
 		}
 #endif
@@ -1494,8 +1502,8 @@ int read_main_configfile(char *configfile, t_config *config, bool config_check)
 	t_directory *current_directory = NULL;
 	t_binding *current_binding = NULL;
 	t_fcgi_server *current_fcgi_server = NULL;
-#ifdef HAVE_REWRITE
-	t_url_rewrite *current_rewrite = NULL;
+#ifdef HAVE_TOOLKIT
+	t_url_toolkit *current_toolkit = NULL;
 #endif
 
 	/* Read and parse Hiawatha configurationfile.
@@ -1568,12 +1576,12 @@ int read_main_configfile(char *configfile, t_config *config, bool config_check)
 					current_host->next = new_host();
 					current_host = current_host->next;
 					section = virtual_host;
-#ifdef HAVE_REWRITE
-				} else if (strcmp(key, "urlrewrite") == 0) {
-					current_rewrite = new_url_rewrite();
-					current_rewrite->next = config->url_rewrite;
-					config->url_rewrite = current_rewrite;
-					section = url_rewrite;
+#ifdef HAVE_TOOLKIT
+				} else if (strcmp(key, "urltoolkit") == 0) {
+					current_toolkit = new_url_toolkit();
+					current_toolkit->next = config->url_toolkit;
+					config->url_toolkit = current_toolkit;
+					section = url_toolkit;
 #endif
 				}
 			} else if (strcmp(key, "}") == 0) {
@@ -1603,10 +1611,10 @@ int read_main_configfile(char *configfile, t_config *config, bool config_check)
 						}
 						break;
 					case fcgi_server:
-						if ((config->fcgi_server->fcgi_id != NULL) && (config->fcgi_server->connect_to != NULL) && (config->fcgi_server->extension.size > 0)) {
+						if ((config->fcgi_server->fcgi_id != NULL) && (config->fcgi_server->connect_to != NULL)) {
 							current_fcgi_server = NULL;
 						} else {
-							fprintf(stderr, "A FastCGIid, Extension or ConnectTo is missing in a FastCGIserver section in %s.\n", configfile);
+							fprintf(stderr, "A FastCGIid or ConnectTo is missing in a FastCGIserver section in %s.\n", configfile);
 							retval = -1;
 						}
 						break;
@@ -1621,12 +1629,12 @@ int read_main_configfile(char *configfile, t_config *config, bool config_check)
 							current_host = config->first_host;
 						}
 						break;
-#ifdef HAVE_REWRITE
-					case url_rewrite:
-						if (current_rewrite->rewrite_id != NULL) {
-							current_rewrite = NULL;
+#ifdef HAVE_TOOLKIT
+					case url_toolkit:
+						if (current_toolkit->toolkit_id != NULL) {
+							current_toolkit = NULL;
 						} else {
-							fprintf(stderr, "A RewriteID is missing in a UrlRewrite section in %s\n", configfile);
+							fprintf(stderr, "A ToolkitID is missing in a UrlToolkit section in %s\n", configfile);
 							retval = -1;
 						}
 						break;
@@ -1659,6 +1667,7 @@ int read_main_configfile(char *configfile, t_config *config, bool config_check)
 								case error:
 								case no_access:
 								case not_found:
+									fprintf(stderr, "Error while including '%s'\n", value);
 									retval = -1;
 									break;
 								case no:
@@ -1707,9 +1716,9 @@ int read_main_configfile(char *configfile, t_config *config, bool config_check)
 								if (fcgi_server_setting(key, value, current_fcgi_server)) {
 									break;
 								}
-#ifdef HAVE_REWRITE
-							} else if (section == url_rewrite) {
-								if (url_rewrite_setting(key, value, current_rewrite)) {
+#ifdef HAVE_TOOLKIT
+							} else if (section == url_toolkit) {
+								if (toolkit_setting(key, value, current_toolkit)) {
 									break;
 								}
 #endif
