@@ -6,8 +6,8 @@
 #include "global.h"
 #include "libip.h"
 #include "mimetype.h"
-#ifdef HAVE_REWRITE
-#include "rewrite.h"
+#ifdef HAVE_TOOLKIT
+#include "toolkit.h"
 #endif
 #include "libfs.h"
 #include "liblist.h"
@@ -168,8 +168,8 @@ typedef struct type_host {
 	char          *imgref_replacement;
 	t_keyvalue    *envir_str;
 	t_keyvalue    *alias;
-#ifdef HAVE_REWRITE
-	t_charlist    rewrite_rules;
+#ifdef HAVE_TOOLKIT
+	t_charlist    toolkit_rules;
 #endif
 #ifdef HAVE_SSL
     bool          require_ssl;
@@ -200,6 +200,7 @@ typedef struct type_config {
 	char          *server_string;
 	t_binding     *binding;
 	t_log_format  log_format;
+	bool          wait_for_cgi;
 #ifdef HAVE_SSL
 	char          *server_key;
 	char          *ca_cert;
@@ -222,8 +223,8 @@ typedef struct type_config {
 	t_host        *first_host;
 	t_directory   *directory;
 	t_throttle    *throttle;
-#ifdef HAVE_REWRITE
-	t_url_rewrite *url_rewrite;
+#ifdef HAVE_TOOLKIT
+	t_url_toolkit *url_toolkit;
 #endif
 	t_cgi_handler *cgi_handler;
 	char          *cgi_wrapper;
