@@ -69,12 +69,15 @@ static void clear_session(t_session *session) {
 	session->uploaded_file = NULL;
 	session->uploaded_size = 0;
 	session->location = NULL;
-#ifdef DEBUG
-	session->status = NULL;
+#ifdef HAVE_TOOLKIT
+	session->toolkit_fastcgi = NULL;
 #endif
 #ifdef HAVE_XSLT
 	session->xslt_file = NULL;
 #endif
+#ifdef DEBUG
+	session->status = NULL;
+#endif
 }
 
 /* Initialize a session-record.
