@@ -60,6 +60,9 @@ typedef struct type_session {
 	long            uploaded_size;
 	char            *location;
 	t_cause_of_301  cause_of_301;
+#ifdef HAVE_TOOLKIT
+	char            *toolkit_fastcgi;
+#endif
 #ifdef HAVE_XSLT
 	char            *xslt_file;
 #endif
