@@ -17,9 +17,7 @@
 #include <sys/file.h>
 #include <sys/time.h>
 #include <sys/stat.h>
-#ifdef OPENBSD
 #include <sys/wait.h>
-#endif
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
@@ -325,7 +323,7 @@ int send_file(t_session *session) {
 		if (session->return_code == 206) {
 			if (send_buffer(session, "Content-Range: bytes ", 21) == -1) {
 				break;
-			} else if (snprintf(value, VALUE_SIZE, "%lld-%lld/%lld\r\n", (long long)send_begin, (long long)send_end, file_size) == -1) {
+			} else if (snprintf(value, VALUE_SIZE, "%lld-%lld/%lld\r\n", (long long)send_begin, (long long)send_end, (long long)file_size) == -1) {
 				break;
 			} else if (send_buffer(session, value, strlen(value)) == -1) {
 				break;
@@ -587,12 +585,14 @@ int execute_cgi(t_session *session) {
 		if ((prevent_CMDi(session->vars) > 0) && (session->config->ban_on_cmdi > 0)) {
 			return rr_CMD_INJECTION;
 		}
-		if ((prevent_CMDi(session->body) > 0) && (session->config->ban_on_cmdi > 0)) {
-			return rr_CMD_INJECTION;
-		}
 		if ((prevent_CMDi(session->cookie) > 0) && (session->config->ban_on_cmdi > 0)) {
 			return rr_CMD_INJECTION;
 		}
+		/*
+		if ((prevent_CMDi(session->body) > 0) && (session->config->ban_on_cmdi > 0)) {
+			return rr_CMD_INJECTION;
+		}
+		*/
 	}
 
 	cgi_info.type = session->cgi_type;
@@ -878,11 +878,9 @@ int execute_cgi(t_session *session) {
 		close(cgi_info.cgi_error);
 	}
 
-#ifdef OPENBSD
-	if (cgi_pid != -1) {
-		waitpid(cgi_pid, NULL, WNOHANG);
+	if (session->config->wait_for_cgi && (cgi_pid != -1)) {
+		waitpid(cgi_pid, NULL, 0);
 	}
-#endif
 
 	switch (retval) {
 		case rs_DISCONNECT:
